.. :changelog:

History
-------

0.3.1 (2017-05-15)
++++++++++++++++++

* Ensure feature DB included in package

0.3.0 (2017-05-15)
++++++++++++++++++

* MoonInfo object additions

  * time of day
  * is feature visible

* LunarFeatureContainer object changes

  * Made constructor club related
  * Load call can check if feature is visible using MoonInfo instance

0.2.1 (2017-04-20)
++++++++++++++++++

* Changed mechanism to determine phase name

0.2.0 (2017-04-16)
++++++++++++++++++

* MoonInfo object additions

  * phase name
  * time from new moon
  * time to new moon
  * time to full moon

0.1.0 (2016-07-18)
++++++++++++++++++

* MoonInfo object that provides basic lunar information

  * age
  * altitude
  * azimuth
  * colongitude
  * fractional phase
  * libration latitude
  * libration longitude
  * next four lunar phases

